searchData={"items":[{"type":"module","title":"EctoDbg","doc":"This module exposes a macro that you can inject into your Repo module so\nthat you can pretty print SQL queries with the parameters espaced into the\nquery. Once you `use` this module in your Repo module, you'll be able to\ncall the injected functions with your query and you can see the formatted\nSQL that Ecto generates.","ref":"EctoDbg.html"},{"type":"macro","title":"EctoDbg.__using__/1","doc":"By using this macro in your Repo module, you will get 6 additional functions added\nto your repo module. This functions are:\n\n* `all_and_log/1` and `all_and_log/2`\n* `one_and_log/1` and `one_and_log/2`\n* `update_all_and_log/1` and `update_all_and_log/2`\n* `delete_all_and_log/1` and `delete_all_and_log/2`\n* `log_all_query/1`\n* `log_one_query/1`\n* `log_update_all_query/1`\n* `log_delete_all_query/1`\n\nThe `*_and_log` functions will output the query and will also execute it with the\ncorresponding Repo function (`all`, `update_all`, and `delete_all`). The one and two\narity versions of these functions align with the Repo functions so that these functions\ncan be used as direct drop in replacements when you need to see what query is actually\nbeing executed by Ecto. The `log_*_query` functions will simply log out the generated\nquery without executing them.\n\nThis macro currently supports the following options that can be used to configured\nhow it behaves:\n\n* `:level` - Specifies the log level for when the SQL query is logged (default: `:debug`).\n\n* `:logger_function` - Specifies the module+function that will be invoked when logging an SQL query.\n  The provided module+function must have an arity of 4 and accept the following\n  parameters: `repo, action, formatted_sql, opts` where opts are the options that\n  were passed to the `use EctoDbg` macro. The default value is: `{EctoDbg, :default_logger}`.","ref":"EctoDbg.html#__using__/1"},{"type":"extras","title":"README","doc":"Easily debug and pretty print your Ecto SQL queries\n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n\n# Contents\n\n- [Installation](#installation)\n- [Example Output](#example-output)\n- [Supporting EctoDbg](#supporting-ectodbg)\n- [Setting Up EctoDbg](#setting-up-ectodbg)\n- [Attribution](#attribution)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"[Available in Hex](https://hex.pm/packages/ecto_dbg), the package can be installed by adding `ecto_dbg` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_dbg, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/ecto_dbg](https://hexdocs.pm/ecto_dbg).","ref":"readme.html#installation"},{"type":"extras","title":"Example Output - README","doc":"After setting up EctoDbg in your application you can expect the following output from your Ecto queries when using the\nEctoDbg helpers:","ref":"readme.html#example-output"},{"type":"extras","title":"Supporting EctoDbg - README","doc":"If you rely on this library help you debug your Ecto queries, it would much appreciated if you can give back\nto the project in order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","ref":"readme.html#supporting-ectodbg"},{"type":"extras","title":"Gold Sponsors - README","doc":"","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Setting Up EctoDbg - README","doc":"After adding `{:ecto_dbg, \"~> 0.1.0\"}` in your `mix.exs` file and running `mix deps.get`, open your `repo.ex` file and\nadd the following contents:\n\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n\n  use EctoDbg\nend\n```\n\nYou can also pass configuration options to `EctoDbg` if you so chose like so (see the `EctoDbg` module docs\nfor more information):\n\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n\n  use EctoDbg, level: :info\nend\n```\n\nWith that in place, any time that you want to inspect a query that is executed by Ecto, all you need to do\nis the following\n\n```elixir\nquery = from user in User\n\nRepo.all_and_log(query)\n```\n\nBy default the `use EctoDbg` macro will inject the debug functions into your repo module for only the `:test` and `:dev`\n`Mix.env()` environments. If you would like to override this default behaviour, you can do that by providing the `:only`\noption (this value should be a subset of the environments that you passed in your `mix.exs` file):\n\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n\n  use EctoDbg, only: :dev\nend\n```\n\nIf your queries are especially large, make sure you update your Logger configuration to [support large log\nmessages](https://hexdocs.pm/logger/1.17.3/Logger.Formatter.html#new/1). Specifically the `:truncate` option.","ref":"readme.html#setting-up-ectodbg"},{"type":"extras","title":"Attribution - README","doc":"- EctoDbg builds upon the [EctoDevLogger](https://github.com/fuelen/ecto_dev_logger) package and has reused some of the\n  code in that project to achieve a slightly different goal.\n- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/).\n- The EctoDbg library leans on the Rust library [sqlformat-rs](https://github.com/shssoichiro/sqlformat-rs) for SQL\n  statement formatting. This is done through a Ruslter NIF I maintain called [sql_fmt](https://github.com/akoutmos/sql_fmt).","ref":"readme.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}